..
  This file is generated by setup.py

DNA curvature analysis
======================

Dnacurve is a Python library, console script, and web application to calculate
the global 3D structure of a B-DNA molecule from its nucleotide sequence
according to the dinucleotide wedge model. Local bending angles and macroscopic
curvature are calculated at each nucleotide.

:Author: `Christoph Gohlke <https://www.cgohlke.com>`_
:License: BSD-3-Clause
:Version: 2026.1.8
:DOI: `10.5281/zenodo.7135499 <https://doi.org/10.5281/zenodo.7135499>`_

Quickstart
----------

Install the dnacurve package and all dependencies from the
`Python Package Index <https://pypi.org/project/dnacurve/>`_::

    python -m pip install -U "dnacurve[all]"

Print the console script usage::

    python -m dnacurve --help

Run the web application::

    python -m dnacurve --web

See `Examples`_ for using the programming interface.

Source code and support are available on
`GitHub <https://github.com/cgohlke/dnacurve>`_.

Requirements
------------

This revision was tested with the following requirements and dependencies
(other versions may work):

- `CPython <https://www.python.org>`_ 3.11.9, 3.12.10, 3.13.11, 3.14.2 64-bit
- `NumPy <https://pypi.org/project/numpy>`_ 2.4.0
- `Matplotlib <https://pypi.org/project/matplotlib/>`_ 3.10.8
- `Flask <https://pypi.org/project/Flask/>`_ 3.1.2 (optional)

Revisions
---------

2026.1.8

- Improve code quality.

2025.12.12

- Remove unused overlapping_chunks function.
- Drop support for Python 3.10, support Python 3.14.

2025.5.8

- Remove deprecated save functions (breaking).
- Remove doctest command line option.

2025.1.1

- Improve type hints.
- Drop support for Python 3.9, support Python 3.13.

2024.5.24

- …

Refer to the CHANGES file for older revisions.

Notes
-----

The algorithms, plots, and PDB format are not meant to be used with very
long sequences. By default, sequences are truncated to 510 nucleotides,
which can be overridden by the user.

The generated PDB files can be visualized interactively using
`UCSF Chimera <https://www.cgl.ucsf.edu/chimera/>`_.

Dnacurve.py was derived from DNACG.PAS (c) 1993, and DNACURVE.CPP (c) 1995.

References
----------

1. Bending and curvature calculations in B-DNA.
   Goodsell DS, Dickerson RE. Nucleic Acids Res 22, 5497-503, 1994.
   See also http://mgl.scripps.edu/people/goodsell/research/bend/index.html.
2. Curved DNA without A-A: experimental estimation of all 16 DNA wedge angles.
   Bolshoy A et al. Proc Natl Acad Sci USA 88, 2312-6, 1991.
3. A comparison of six DNA bending models.
   Tan RK and Harvey SC. J Biomol Struct Dyn 5, 497-512, 1987.
4. Curved DNA: design, synthesis, and circularization.
   Ulanovsky L et al. Proc Natl Acad Sci USA 83, 862-6, 1986.
5. The ten helical twist angles of B-DNA.
   Kabsch W, Sander C, and Trifonov EN. Nucleic Acids Res 10, 1097-1104, 1982.
6. Rod models of DNA: sequence-dependent anisotropic elastic modelling of
   local bending phenomena.
   Munteanu MG et al. Trends Biochem Sci 23(9), 341-7, 1998.

Examples
--------

.. code-block:: python

    >>> from dnacurve import CurvedDNA
    >>> cdna = CurvedDNA('ATGCAAATTG' * 5, 'trifonov', name='Example')
    >>> cdna.curvature[:, 18:22]
    array([[0.58061616, 0.58163338, 0.58277938, 0.583783  ],
           [0.08029914, 0.11292516, 0.07675816, 0.03166286],
           [0.57923902, 0.57580064, 0.57367815, 0.57349872]])
    >>> cdna.write_csv('_test.csv')
    >>> cdna.write_pdb('_test.pdb')
    >>> cdna.plot('_test.png', dpi=120)